@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2011 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: delay.cpp,v 1.4 2011/02/24 16:43:54 cvs Exp $
+//      $Id: delay.cpp,v 1.5 2011/08/16 22:26:19 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -22,10 +22,11 @@
 
 #include "delay.h"
 
-Delay::Delay(Profile *p,int id,QObject *parent,const char *name)
+Delay::Delay(Profile *p,int id,bool debug,QObject *parent,const char *name)
   : QObject(parent,name)
 {
   delay_id=id;
+  delay_debug=debug;
 }
 
 
@@ -34,6 +35,12 @@ Delay::~Delay()
 }
 
 
+bool Delay::debugMode() const
+{
+  return delay_debug;
+}
+
+
 int Delay::id() const
 {
   return delay_id;
