@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2011 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: cmdswitch.h,v 1.1 2011/02/17 22:45:41 cvs Exp $
+//      $Id: cmdswitch.h,v 1.2 2012/07/27 17:16:50 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -29,7 +29,7 @@
 class CmdSwitch
 {
  public:
-  CmdSwitch(int argc,char *argv[],char *modname,char *usage);
+  CmdSwitch(int argc,char *argv[],const char *modname,const char *usage);
   unsigned keys() const;
   QString key(unsigned n) const;
   QString value(unsigned n) const;
